OC.L10N.register(
    "logreader",
    {
    "Error parsing log" : "Produciuse un erro ao analizar o rexistro",
    "Copy" : "Copiar",
    "Copy raw" : "Copia básica",
    "Copy formatted" : "Copia formatda",
    "No server logs" : "Non hai rexistros no servidor",
    "One or more entries are hidden by the log level filter" : "Unha ou máis entradas están agochadas polo filtro de nivel do rexistro",
    "Everything is working fine" : "Todo está a funcionar ben",
    "Level" : "Nivel",
    "App" : "Aplicación",
    "Message" : "Mensaxe",
    "Time" : "Hora",
    "Log levels" : "Níveis do registro",
    "Log content" : "Contido do rexistro",
    "Live update" : "Actualización ao vivo",
    "Download logs" : "Descargar rexistros",
    "Logging" : "Rexistrando",
    "Log Reader" : "Lector de rexistros",
    "A log reader for Nextcloud" : "Un lector de rexistros para o Nextcloud",
    "Log reader for Nextcloud" : "Lector de rexistros para o Nextcloud",
    "Cased by " : "Cased by "
},
"nplurals=2; plural=(n != 1);");
